summaryrefslogtreecommitdiffstats
path: root/kontact/plugins/korganizer/todosummarywidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kontact/plugins/korganizer/todosummarywidget.cpp')
-rw-r--r--kontact/plugins/korganizer/todosummarywidget.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kontact/plugins/korganizer/todosummarywidget.cpp b/kontact/plugins/korganizer/todosummarywidget.cpp
index 1109f314..8d78d372 100644
--- a/kontact/plugins/korganizer/todosummarywidget.cpp
+++ b/kontact/plugins/korganizer/todosummarywidget.cpp
@@ -53,8 +53,8 @@
#include "todosummarywidget.h"
TodoSummaryWidget::TodoSummaryWidget( TodoPlugin *plugin,
- TQWidget *tqparent, const char *name )
- : Kontact::Summary( tqparent, name ), mPlugin( plugin )
+ TQWidget *parent, const char *name )
+ : Kontact::Summary( parent, name ), mPlugin( plugin )
{
TQVBoxLayout *mainLayout = new TQVBoxLayout( this, 3, 3 );
@@ -152,7 +152,7 @@ void TodoSummaryWidget::updateView()
mLabels.append( label );
TQString sSummary = todo->summary();
- if ( todo->relatedTo() ) { // show tqparent only, not entire ancestry
+ if ( todo->relatedTo() ) { // show parent only, not entire ancestry
sSummary = todo->relatedTo()->summary() + ":" + todo->summary();
}
KURLLabel *urlLabel = new KURLLabel( this );